function Orfanidi2016CoatedGlass(varargin)
% Duplicate Fig. 6.2.1 in [Orfanidi2016] on Page 190.
%
%

addpath('../src');

background = DielectricMaterial(1, 0);
wavelength=linspace(400e-9, 700e-9, 101);
f = getPhaseVelocity(background, 1)./wavelength;

glass = DielectricMaterial(1.5^2, 0);
m1 = DielectricMaterial(1.38^2, 0); 
m2 = DielectricMaterial(2.45^2, 0); 
m3 = DielectricMaterial(1.22^2, 0); 

% Ga
layer = {m1, m2, glass};
z = [0, 
     0.3294*550e-9/1.38,
     0.0453*550e-9/2.45];
z = cumsum(z);
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, background, f);
ref_1 = ref(:,1);

% Gb
layer = {m1, glass};
z = [0, 550e-9/4/1.38];
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, background, f);
ref_2 = ref(:,1);

% Gc
layer = {m3, glass};
z = [0, 550e-9/4/1.22];
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, background, f);
ref_3 = ref(:,1);

figure;
set(gcf, 'color', 'white');
plot(wavelength*1e9, abs(ref_1).^2*100, 'color', [0,0,0], 'LineStyle', '-');
hold('on');
plot(wavelength*1e9, abs(ref_2).^2*100, 'color', [0.2,0.2,0.2], 'LineStyle','--');
plot(wavelength*1e9, abs(ref_3).^2*100, 'color', [0.4,0.4,0.4], 'LineStyle','-.');
set(gca, 'fontname', 'arial', 'fontsize', 12);
set(gca, 'xlim', [400 700], 'xtick', 400:50:700);
set(gca, 'ylim', [0 4], 'ytick', 0:1:4);
xlabel('\lambda (nm)');
ylabel('|\Gamma(\lambda)|^2 (percent)');
legend('air | 1.38 | 2.45 | glass', 'air | 1.38 | glass', ...
       'air | 1.22 | glass');
title('Antireflection coatings on glass');

end
