function Orfanidi2016DielectricMirror(varargin)
% Duplicate Fig. 6.3.2 in [Orfanidi2016] on Page 199.
%

addpath('../src');

background = DielectricMaterial(1, 0); % air
lambda_0=500; % (nm)
n_H = DielectricMaterial(2.32^2, 0); % zinc sulfide 
n_L = DielectricMaterial(1.38^2, 0); % manesium fluoride
glass = DielectricMaterial(1.52^2, 0); % glass


lambda=linspace(300, 800, 256); % (nm)
f = getPhaseVelocity(background, 1)./(lambda*1e-9);

% N=2
layer = {n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         glass};
z = [0
     lambda_0/4/2.32
     repmat([lambda_0/4/1.38; lambda_0/4/2.32], 2, 1)
     ];
z = cumsum(z)*1e-9;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, ...
                                                       background, f);
ref_1 = ref(:,1);

% N=4
layer = {n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         glass};
z = [0
     lambda_0/4/2.32
     repmat([lambda_0/4/1.38; lambda_0/4/2.32], 4, 1)
    ];
z = cumsum(z)*1e-9;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, background, f);
ref_2 = ref(:,1);


% N=8
layer = {n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         n_L, n_H, ...
         glass};
z = [0
     lambda_0/4/2.32
     repmat([lambda_0/4/1.38; lambda_0/4/2.32], 8, 1)
    ];
z = cumsum(z)*1e-9;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, background, f);
ref_3 = ref(:,1);

% N=8
f_0 = getPhaseVelocity(background, 1)./(lambda_0*1e-9);
f = linspace(0, 6, 512)*f_0;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, background, f);
ref_4 = ref(:,1);

     
figure; 
set(gcf, 'color', 'white');
plot(lambda, abs(ref_1).^2*100, 'color', [0,0,0], 'LineStyle', '-.');
hold('on');
plot(lambda, abs(ref_2).^2*100, 'color', [0.2,0.2,0.2], 'LineStyle', '--');
plot(lambda, abs(ref_3).^2*100, 'color', [0.4,0.4,0.4], 'LineStyle', '-');
set(gca, 'fontname', 'arial', 'fontsize', 12);
set(gca, 'xlim', [min(lambda) max(lambda)], 'xtick', min(lambda):100:max(lambda));
set(gca, 'ylim', [0 110], 'ytick', 0:20:100);
xlabel('\lambda (nm)');
ylabel('|\Gamma(\lambda)|^2 (percent)');
title('Dielectric mirror reflection response');
legend('N=2', 'N=4', 'N=8', 'location', 'northeast');

figure;
set(gcf, 'color', 'white');
plot(f/f_0, abs(ref_4).^2*100, 'color', [0,0,0], 'LineStyle', '-');
set(gca, 'fontname', 'arial', 'fontsize', 12);
set(gca, 'xlim', [0 6], 'xtick', 0:1:6);
set(gca, 'ylim', [0 110], 'ytick', 0:20:100);
xlabel('f/f_0');
ylabel('|\Gamma(\lambda)|^2 (percent)');
title('Dielectric mirror reflection response');
