function Orfanidi2016TransmissionFilter(varargin)
% Duplicate Fig. 6.5.1 in [Orfanidi2016] on Page 206. Phase shifted
% Fabry-Perot resonator.
%

addpath('../src');

n_a = DielectricMaterial(1.52^2, 0);
n_b = DielectricMaterial(1.52^2, 0);
n_H = DielectricMaterial(2.10^2, 0);
n_L = DielectricMaterial(1.40^2, 0);

lambda_0 = 1550; % (nm);

lambda = [linspace(1200, 1400, 64) ...
          linspace(1400, 1500, 128) ...
          linspace(1500, 1600, 32) ...
          linspace(1600, 1700, 128) ...
          linspace(1700, 2000, 64)];
f = getPhaseVelocity(DielectricMaterial(1, 0), 1)./(lambda*1e-9);

% G(HL)^6G
layer = {n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_b};
z = [0
     repmat([lambda_0/4/2.1; lambda_0/4/1.4], 6, 1)
    ];
z = cumsum(z)*1e-9;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, n_a, f);
ref_1 = ref(:,1);

% G(HL)^6(1.3L)(HL)^6LG
layer = {n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_L, ...
         n_b};
z = [0
     repmat([lambda_0/4/2.1; lambda_0/4/1.4], 6, 1)
     1.3*lambda_0/4/1.4
     repmat([lambda_0/4/2.1; lambda_0/4/1.4], 6, 1)
     lambda_0/4/1.4
    ];
z = cumsum(z)*1e-9;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, n_a, f);
ref_2 = ref(:,1);


% G(HL)^6(0.6L)(HL)^6LG
layer = {n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_H, n_L, ...
         n_L, ...
         n_b};
z = [0
     repmat([lambda_0/4/2.1; lambda_0/4/1.4], 6, 1)
     0.6*lambda_0/4/1.4
     repmat([lambda_0/4/2.1; lambda_0/4/1.4], 6, 1)
     lambda_0/4/1.4
    ];
z = cumsum(z)*1e-9;
ref = getCoefficientByMultilayerPlaneUnderPlaneWave(z, layer, n_a, f);
ref_3 = ref(:,1);

figure; 
set(gcf, 'color', 'white');
plot(lambda, (1-abs(ref_1).^2)*100, 'color', [0,0,0], 'LineStyle', '-.');
hold('on');
plot(lambda, (1-abs(ref_2).^2)*100, 'color', [0,0,0], 'LineStyle', '--');
plot(lambda, (1-abs(ref_3).^2)*100, 'color', [0,0,0], 'LineStyle', '-');

set(gca, 'fontname', 'arial', 'fontsize', 12);
set(gca, 'xlim', [min(lambda) max(lambda)], 'xtick', min(lambda):200:max(lambda));
set(gca, 'ylim', [0 110], 'ytick', 0:20:100);
grid('on');

xlabel('\lambda (nm)');
ylabel('Transmittance (percent)');
legend('G(HL)^6G', 'G(HL)^6(1.3L)(HL)^6LG', 'G(HL)^6(0.6L)(HL)^6LG')
title('Phase-shifted Fabry-Perot resonator');

